@@ -1,4 +1,4 @@
-/* $Id: xfsm-util.c 24158 2006-12-21 21:50:25Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
  * Copyright (c) 2004 Jasper Huijsmans <jasper@xfce.org>
@@ -8,12 +8,12 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- *                                                                              
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *                                                                              
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -38,45 +38,11 @@
 
 #include <gdk/gdkx.h>
 
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include <libxfsm/xfsm-util.h>
 
 
-GtkWidget *
-xfsm_imgbtn_new(const gchar *text, const gchar *icon, GtkWidget **label_ret)
-{
-	GtkWidget *button;
-	GtkWidget *align;
-	GtkWidget *image;
-	GtkWidget *hbox;
-  GtkWidget *label;
-
-	button = gtk_button_new();
-
-	align = gtk_alignment_new(0.5f, 0.5f, 0.0f, 0.0f);
-	gtk_container_add(GTK_CONTAINER(button), align);
-	gtk_widget_show(align);
-
-	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_container_add(GTK_CONTAINER(align), hbox);
-	gtk_widget_show(hbox);
-
-	image = gtk_image_new_from_stock(icon, GTK_ICON_SIZE_BUTTON);
-	gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 2);
-	gtk_widget_show(image);
-
-	label = gtk_label_new_with_mnemonic(text);
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);
-	gtk_widget_show(label);
-
-  if (label_ret != NULL)
-    *label_ret = label;
-
-	return button;
-}
-
-
 gboolean
 xfsm_start_application (gchar      **command,
                         gchar      **environment,
@@ -101,15 +67,21 @@ xfsm_start_application (gchar      **command,
     {
       /* setting current directory on a remote machine is not supported */
       current_directory = NULL;
-      
+
       argv[argc++] = g_strdup ("xon");
       argv[argc++] = g_strdup (client_machine);
     }
-  
+
   if (screen != NULL)
     {
       if (client_machine != NULL)
-        screen_name = xfce_gdk_screen_get_fullname (screen);
+        {
+          gchar *display_name =
+            xfsm_gdk_display_get_fullname (gdk_screen_get_display (screen));
+
+          screen_name = g_strdup_printf ("%s.%d", display_name,
+                                         gdk_screen_get_number (screen));
+        }
       else
         screen_name = gdk_screen_make_display_name (screen);
       argv[argc++] = g_strdup ("env");
@@ -124,12 +96,12 @@ xfsm_start_application (gchar      **command,
           size *= 2;
           argv = g_realloc (argv, (size + 1) * sizeof (*argv));
         }
-      
+
       argv[argc++] = xfce_expand_variables (*command, environment);
     }
 
   argv[argc] = NULL;
-  
+
   result = g_spawn_async (current_directory,
                           argv,
                           environment,
@@ -138,9 +110,9 @@ xfsm_start_application (gchar      **command,
                           NULL,
                           NULL,
                           NULL);
-  
+
   g_strfreev (argv);
-  
+
   return result;
 }
 
@@ -160,24 +132,6 @@ xfsm_place_trash_window (GtkWindow *window,
 }
 
 
-gchar**
-xfsm_strv_copy (gchar **v)
-{
-  gchar **rv;
-  gsize len;
-  gsize n;
-
-  for (len = 0; v[len] != NULL; ++len) ;
-
-  rv = g_new (gchar *, len + 1);
-  for (n = 0; n < len; ++n)
-    rv[n] = g_strdup (v[n]);
-  rv[n] = NULL;
-
-  return rv;
-}
-
-
 gboolean
 xfsm_strv_equal (gchar **a, gchar **b)
 {
@@ -203,11 +157,11 @@ void
 xfsm_window_add_border (GtkWindow *window)
 {
   GtkWidget *box1, *box2;
-  
+
   gtk_widget_realize(GTK_WIDGET(window));
 
   box1 = gtk_event_box_new ();
-  gtk_widget_modify_bg (box1, GTK_STATE_NORMAL, 
+  gtk_widget_modify_bg (box1, GTK_STATE_NORMAL,
                         &(GTK_WIDGET(window)->style->bg [GTK_STATE_SELECTED]));
   gtk_widget_show (box1);
 
@@ -234,11 +188,48 @@ xfsm_window_grab_input (GtkWindow *window)
 }
 
 
-XfceRc*
-xfsm_open_config (gboolean readonly)
+XfconfChannel*
+xfsm_open_config (void)
 {
-  return xfce_rc_config_open (XFCE_RESOURCE_CONFIG,
-                              "xfce4-session/xfce4-session.rc",
-                              readonly);
+  return xfconf_channel_get ("xfce4-session");
+}
+
+gchar*
+xfsm_gdk_display_get_fullname (GdkDisplay *display)
+{
+  const gchar *name;
+  const gchar *np;
+  gchar       *hostname;
+  gchar        buffer[256];
+  gchar       *bp;
+
+  g_return_val_if_fail (GDK_IS_DISPLAY (display), NULL);
+
+  name = gdk_display_get_name (display);
+  if (*name == ':')
+    {
+      hostname = xfce_gethostname ();
+      g_strlcpy (buffer, hostname, 256);
+      g_free (hostname);
+
+      bp = buffer + strlen (buffer);
+
+      for (np = name; *np != '\0' && *np != '.' && bp < buffer + 255; )
+        *bp++ = *np++;
+      *bp = '\0';
+    }
+  else
+    {
+      g_strlcpy (buffer, name, 256);
+
+      for (bp = buffer + strlen (buffer) - 1; *bp != ':'; --bp)
+        if (*bp == '.')
+          {
+            *bp = '\0';
+            break;
+          }
+    }
+
+  return g_strdup (buffer);
 }
 
