@@ -1,4 +1,4 @@
-/* $Id: xfsm-util.h 20833 2006-04-09 18:08:17Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -22,14 +22,15 @@
 #ifndef __XFSM_UTIL_H__
 #define __XFSM_UTIL_H__
 
+#include <xfconf/xfconf.h>
+
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 G_BEGIN_DECLS;
 
-GtkWidget	*xfsm_imgbtn_new(const gchar *, const gchar *, GtkWidget **);
-
 gboolean xfsm_start_application (gchar      **command,
                                  gchar      **environment,
                                  GdkScreen   *screen,
@@ -42,14 +43,16 @@ void xfsm_place_trash_window (GtkWindow *window,
                               gint       monitor);
 
 /* XXX - move to libxfce4util? */
-gchar **xfsm_strv_copy (gchar **v);
 gboolean xfsm_strv_equal (gchar **a, gchar **b);
 
 void xfsm_window_add_border (GtkWindow *window);
 
 void xfsm_window_grab_input (GtkWindow *window);
 
-XfceRc *xfsm_open_config (gboolean readonly);
+XfconfChannel *xfsm_open_config (void);
+
+gchar *xfsm_gdk_display_get_fullname (GdkDisplay *display);
+
 
 G_END_DECLS;
 
