@@ -1,26 +1,24 @@
-/* $Id$ */
+/* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * Copyright (c) 2008 Brian Tarricone <bjt23@cornell.edu>
+ * Copyright (c) 2010 Jannis Pohlmann <jannis@xfce.org>
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *                                                                              
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *                                                                              
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
  *
- * The session id generator was taken from the KDE session manager.
- * Copyright (c) 2000 Matthias Ettrich <ettrich@kde.org>
+ * You should have received a copy of the GNU General Public
+ * License along with this program; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -118,13 +116,6 @@ struct _XfsmManager
   guint            die_timeout_id;
 
   DBusGConnection *session_bus;
-
-
-#ifdef ENABLE_CONSOLE_KIT
-  DBusGConnection *system_bus;
-  DBusGProxy      *consolekit_proxy;
-  gchar           *consolekit_cookie;
-#endif
 };
 
 typedef struct _XfsmManagerClass
@@ -180,10 +171,6 @@ static void       xfsm_manager_dbus_class_init (XfsmManagerClass *klass);
 static void       xfsm_manager_dbus_init (XfsmManager *manager);
 static void       xfsm_manager_dbus_cleanup (XfsmManager *manager);
 
-#ifdef ENABLE_CONSOLE_KIT
-static void       xfsm_manager_consolekit_init (XfsmManager *manager);
-static void       xfsm_manager_consolekit_cleanup (XfsmManager *manager);
-#endif /*ENABLE_CONSOLE_KIT*/
 
 static guint signals[N_SIGS] = { 0, };
 
@@ -234,39 +221,16 @@ xfsm_manager_class_init (XfsmManagerClass *klass)
 static void
 xfsm_manager_init (XfsmManager *manager)
 {
-#ifdef ENABLE_CONSOLE_KIT
-  GError *error = NULL;
-#endif
-
   manager->state = XFSM_MANAGER_STARTUP;
   manager->session_chooser = FALSE;
   manager->failsafe_mode = TRUE;
   manager->shutdown_type = XFSM_SHUTDOWN_LOGOUT;
 
-#ifdef ENABLE_CONSOLE_KIT
-  manager->consolekit_proxy  = NULL;
-  manager->consolekit_cookie = NULL;
-#endif /*ENABLE_CONSOLE_KIT*/
-
   manager->pending_properties = g_queue_new ();
   manager->starting_properties = g_queue_new ();
   manager->restart_properties = g_queue_new ();
   manager->running_clients = g_queue_new ();
   manager->failsafe_clients = g_queue_new ();
-
-#ifdef ENABLE_CONSOLE_KIT
-  manager->system_bus = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
-  
-  if ( G_LIKELY (manager->system_bus != NULL) )
-    {
-      xfsm_manager_consolekit_init (manager);
-    }
-  else if ( error )
-    {
-      g_warning ("Failed to connect to the system bus : %s", error->message);
-      g_error_free (error);
-    }
-#endif
 }
 
 static void
@@ -276,13 +240,6 @@ xfsm_manager_finalize (GObject *obj)
 
   xfsm_manager_dbus_cleanup (manager);
 
-#ifdef ENABLE_CONSOLE_KIT
-  xfsm_manager_consolekit_cleanup (manager);
-  
-  if ( manager->system_bus )
-    dbus_g_connection_unref (manager->system_bus);
-#endif /*ENABLE_CONSOLE_KIT*/
-
   if (manager->die_timeout_id != 0)
     g_source_remove (manager->die_timeout_id);
 
@@ -342,73 +299,6 @@ xfsm_manager_new (void)
   return manager;
 }
 
-#ifdef ENABLE_CONSOLE_KIT
-static void xfsm_manager_consolekit_init (XfsmManager *manager)
-{
-  GError *error = NULL;
-  gboolean ret;
-  
-  manager->consolekit_proxy = dbus_g_proxy_new_for_name_owner (manager->system_bus,
-							       "org.freedesktop.ConsoleKit",
-							       "/org/freedesktop/ConsoleKit/Manager",
-							       "org.freedesktop.ConsoleKit.Manager",
-							       NULL);
-
-  
-  if ( G_UNLIKELY (!manager->consolekit_proxy) )
-    {
-      g_warning ("Failed to create proxy for 'org.freedesktop.ConsoleKit'");
-      return;
-    }
-
-  ret = dbus_g_proxy_call (manager->consolekit_proxy, "OpenSession", &error,
-			   G_TYPE_INVALID,
-			   G_TYPE_STRING, &manager->consolekit_cookie,
-			   G_TYPE_INVALID);
-
-  if ( G_LIKELY (ret) )
-    {
-      /*
-       * ConsoleKit doc says that the leader session should set the cookie
-       * on XDG_SESSION_COOKIE env variable.
-       */
-      g_warn_if_fail (g_setenv ("XDG_SESSION_COOKIE",
-				manager->consolekit_cookie,
-				TRUE));
-    }
-  else if ( error )
-    {
-      g_warning ("OpenSession on 'org.freedesktop.ConsoleKit' failed with %s", error->message);
-      g_error_free (error);
-    }
-}
-
-static void xfsm_manager_consolekit_cleanup (XfsmManager *manager)
-{
-  if ( manager->consolekit_proxy )
-    {
-      if (manager->consolekit_cookie) 
-	{
-	  GError *error = NULL;
-	  gboolean ret, result;
-	  
-	  ret = dbus_g_proxy_call (manager->consolekit_proxy, "CloseSession", &error,
-				   G_TYPE_STRING, manager->consolekit_cookie,
-				   G_TYPE_INVALID,
-				   G_TYPE_BOOLEAN, &result,
-				   G_TYPE_INVALID);
-	  if ( !ret )
-	    {
-	      g_warning ("CloseSession on 'org.freedesktop.ConsoleKit' failed with %s", error->message);
-	      g_error_free (error);
-	    }
-	  g_free (manager->consolekit_cookie);
-	}
-      g_object_unref (manager->consolekit_proxy);
-    }
-}
-#endif /*ENABLE_CONSOLE_KIT*/
-
 
 static gboolean
 xfsm_manager_startup (XfsmManager *manager)
@@ -644,14 +534,14 @@ xfsm_manager_load_session (XfsmManager *manager)
   gchar           buffer[1024];
   XfceRc         *rc;
   gint            count;
-  
+
   if (!g_file_test (manager->session_file, G_FILE_TEST_IS_REGULAR))
     return FALSE;
 
   rc = xfce_rc_simple_open (manager->session_file, FALSE);
   if (G_UNLIKELY (rc == NULL))
     return FALSE;
-  
+
   if (manager->session_chooser && !xfsm_manager_choose_session (manager, rc))
     {
       xfce_rc_close (rc);
@@ -659,7 +549,7 @@ xfsm_manager_load_session (XfsmManager *manager)
     }
 
   g_snprintf (buffer, 1024, "Session: %s", manager->session_name);
-  
+
   xfce_rc_set_group (rc, buffer);
   count = xfce_rc_read_int_entry (rc, "Count", 0);
   if (G_UNLIKELY (count <= 0))
@@ -667,7 +557,7 @@ xfsm_manager_load_session (XfsmManager *manager)
       xfce_rc_close (rc);
       return FALSE;
     }
-  
+
   while (count-- > 0)
     {
       g_snprintf (buffer, 1024, "Client%d_", count);
@@ -780,7 +670,7 @@ xfsm_manager_load_settings (XfsmManager   *manager,
                             XfconfChannel *channel)
 {
   gboolean session_loaded = FALSE;
-  
+
   manager->session_name = xfconf_channel_get_string (channel,
                                                      "/general/SessionName",
                                                      DEFAULT_SESSION_NAME);
@@ -879,7 +769,7 @@ xfsm_manager_restart (XfsmManager *manager)
   g_object_unref (preview);
 
   g_idle_add ((GSourceFunc) xfsm_manager_startup, manager);
-  
+
   return TRUE;
 }
 
@@ -1023,7 +913,7 @@ xfsm_manager_register_client (XfsmManager *manager,
 
   g_signal_emit (manager, signals[SIG_CLIENT_REGISTERED], 0,
                  xfsm_client_get_object_path (client));
-  
+
   if (previous_id == NULL)
     {
       SmsSaveYourself (sms_conn, SmSaveLocal, False, SmInteractStyleNone, False);
@@ -1054,7 +944,7 @@ xfsm_manager_start_interact (XfsmManager *manager,
   /* notify client of interact */
   SmsInteract (xfsm_client_get_sms_connection (client));
   xfsm_client_set_state (client, XFSM_CLIENT_INTERACTING);
-  
+
   /* stop save yourself timeout */
   xfsm_manager_cancel_client_save_timeout (manager, client);
 }
@@ -1095,7 +985,7 @@ xfsm_manager_interact (XfsmManager *manager,
               return;
             }
         }
-  
+
       xfsm_manager_start_interact (manager, client);
     }
 }
@@ -1125,9 +1015,9 @@ xfsm_manager_interact_done (XfsmManager *manager,
       xfsm_manager_close_connection (manager, client, TRUE);
       return;
     }
-  
+
   xfsm_client_set_state (client, XFSM_CLIENT_SAVING);
-  
+
   /* Setting the cancel-shutdown field to True indicates that the user
    * has requested that the entire shutdown be cancelled. Cancel-
    * shutdown may only be True if the corresponding SaveYourself
@@ -1139,7 +1029,7 @@ xfsm_manager_interact_done (XfsmManager *manager,
     {
       /* we go into checkpoint state from here... */
       xfsm_manager_set_state (manager, XFSM_MANAGER_CHECKPOINT);
-      
+
       /* If a shutdown is in progress, the user may have the option
        * of cancelling the shutdown. If the shutdown is cancelled
        * (specified in the "Interact Done" message), the session
@@ -1181,6 +1071,7 @@ xfsm_manager_interact_done (XfsmManager *manager,
   xfsm_manager_start_client_save_timeout (manager, client);
 }
 
+
 static void
 xfsm_manager_save_yourself_global (XfsmManager     *manager,
                                    gint             save_type,
@@ -1222,8 +1113,8 @@ xfsm_manager_save_yourself_global (XfsmManager     *manager,
           shutdown_helper = xfsm_shutdown_helper_new ();
 
           if (!xfsm_shutdown_helper_send_command (shutdown_helper,
-						  manager->shutdown_type,
-						  &error))
+                                                  manager->shutdown_type,
+                                                  &error))
             {
               xfce_message_dialog (NULL, _("Shutdown Failed"),
                                    GTK_STOCK_DIALOG_ERROR,
@@ -1237,7 +1128,7 @@ xfsm_manager_save_yourself_global (XfsmManager     *manager,
             }
 
           /* clean up and return */
-	  g_object_unref (shutdown_helper);
+          g_object_unref (shutdown_helper);
 
 
           /* at this point, either we failed to suspend/hibernate, or we
@@ -1273,7 +1164,7 @@ xfsm_manager_save_yourself_global (XfsmManager     *manager,
                               shutdown
                               ? XFSM_MANAGER_SHUTDOWN
                               : XFSM_MANAGER_CHECKPOINT);
-      
+
       /* handle legacy applications first! */
       xfsm_legacy_perform_session_save ();
 
@@ -1299,7 +1190,7 @@ xfsm_manager_save_yourself_global (XfsmManager     *manager,
 
           xfsm_client_set_state (client, XFSM_CLIENT_SAVING);
           xfsm_manager_start_client_save_timeout (manager, client);
-        } 
+        }
     }
   else
     {
@@ -1334,7 +1225,7 @@ xfsm_manager_save_yourself (XfsmManager *manager,
       xfsm_manager_close_connection (manager, client, TRUE);
       return;
     }
-  
+
   if (!global)
     {
       /* client requests a local checkpoint. We slightly ignore
@@ -1381,7 +1272,7 @@ xfsm_manager_save_yourself_done (XfsmManager *manager,
       xfsm_verbose ("Client Id = %s send SAVE YOURSELF DONE, while not being "
                     "in save mode. Prepare to be nuked!\n",
                     xfsm_client_get_id (client));
-      
+
       xfsm_manager_close_connection (manager, client, TRUE);
     }
 
@@ -1416,7 +1307,7 @@ xfsm_manager_close_connection (XfsmManager *manager,
 {
   IceConn ice_conn;
   GList *lp;
-  
+
   xfsm_client_set_state (client, XFSM_CLIENT_DISCONNECTED);
   xfsm_manager_cancel_client_save_timeout (manager, client);
 
@@ -1428,7 +1319,7 @@ xfsm_manager_close_connection (XfsmManager *manager,
       IceSetShutdownNegotiation (ice_conn, False);
       IceCloseConnection (ice_conn);
     }
-  
+
   if (manager->state == XFSM_MANAGER_SHUTDOWNPHASE2)
     {
       for (lp = g_queue_peek_nth_link (manager->running_clients, 0);
@@ -1439,7 +1330,7 @@ xfsm_manager_close_connection (XfsmManager *manager,
           if (xfsm_client_get_state (cl) != XFSM_CLIENT_DISCONNECTED)
             return;
         }
-      
+
       /* all clients finished the DIE phase in time */
       if (manager->die_timeout_id)
         {
@@ -1453,7 +1344,7 @@ xfsm_manager_close_connection (XfsmManager *manager,
       xfsm_verbose ("Client Id = %s, closed connection in checkpoint state\n"
                     "   Session manager will show NO MERCY\n\n",
                     xfsm_client_get_id (client));
-      
+
       /* stupid client disconnected in CheckPoint state, prepare to be nuked! */
       g_queue_remove (manager->running_clients, client);
       g_object_unref (client);
@@ -1462,7 +1353,7 @@ xfsm_manager_close_connection (XfsmManager *manager,
   else
     {
       XfsmProperties *properties = xfsm_client_steal_properties (client);
-      
+
       if (properties != NULL)
         {
           if (xfsm_properties_check (properties))
@@ -1601,7 +1492,7 @@ xfsm_manager_check_clients_saving (XfsmManager *manager)
             break;
         }
     }
-  
+
   return FALSE;
 }
 
@@ -1611,13 +1502,13 @@ xfsm_manager_maybe_enter_phase2 (XfsmManager *manager)
 {
   gboolean entered_phase2 = FALSE;
   GList *lp;
-  
+
   for (lp = g_queue_peek_nth_link (manager->running_clients, 0);
        lp;
        lp = lp->next)
-    { 
+    {
       XfsmClient *client = lp->data;
-      
+
       if (xfsm_client_get_state (client) == XFSM_CLIENT_WAITFORPHASE2)
         {
           entered_phase2 = TRUE;
@@ -1644,12 +1535,12 @@ xfsm_manager_complete_saveyourself (XfsmManager *manager)
    */
   if (xfsm_manager_check_clients_saving (manager) || xfsm_manager_maybe_enter_phase2 (manager))
     return;
-  
+
   xfsm_verbose ("Manager finished SAVE YOURSELF, session data will be stored now.\n\n");
-  
+
   /* all clients done, store session data */
   xfsm_manager_store_session (manager);
-  
+
   if (manager->state == XFSM_MANAGER_CHECKPOINT)
     {
       /* reset all clients to idle state */
@@ -1675,7 +1566,7 @@ static gboolean
 xfsm_manager_save_timeout (gpointer user_data)
 {
   XfsmSaveTimeoutData *stdata = user_data;
-  
+
   xfsm_verbose ("Client id = %s, received SAVE TIMEOUT\n"
                 "   Client will be disconnected now.\n\n",
                 xfsm_client_get_id (stdata->client));
@@ -1684,7 +1575,7 @@ xfsm_manager_save_timeout (gpointer user_data)
 
   /* returning FALSE below will free the data */
   g_object_steal_data (G_OBJECT (stdata->client), "--save-timeout-id");
-  
+
   return FALSE;
 }
 
@@ -1787,7 +1678,7 @@ xfsm_manager_store_session (XfsmManager *manager)
                                                       SmRestartIfRunning);
       if (restart_style_hint == SmRestartNever)
         continue;
-      
+
       g_snprintf (prefix, 64, "Client%d_", count);
       xfsm_properties_store (xfsm_client_get_properties (client), rc, prefix);
       ++count;
@@ -1804,7 +1695,7 @@ xfsm_manager_store_session (XfsmManager *manager)
     {
       screen = wnck_screen_get (n);
       wnck_screen_force_update (screen);
-      
+
       workspace = wnck_screen_get_active_workspace (screen);
       m = wnck_workspace_get_number (workspace);
 
