@@ -1,4 +1,4 @@
-/* $Id: xfsm-splash-screen.c 23142 2006-09-13 15:52:01Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -32,8 +32,9 @@
 
 #include <gmodule.h>
 
+#include <xfconf/xfconf.h>
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include <libxfsm/xfsm-splash-engine.h>
 #include <libxfsm/xfsm-util.h>
@@ -62,11 +63,12 @@ xfsm_splash_screen_new (GdkDisplay  *display,
   GdkScreen        *screen;
   gchar             name[128];
   int               monitor;
-  XfceRc           *rc;
+  XfconfChannel    *channel;
 
   /* locate monitor with pointer */
-  screen = xfce_gdk_display_locate_monitor_with_pointer (display, &monitor);
-  if (G_UNLIKELY (screen == NULL))
+  screen = xfce_gdk_screen_get_active (&monitor);
+
+  if (G_UNLIKELY (screen == NULL) || (gdk_screen_get_display (screen) != display))
     {
       screen  = gdk_display_get_screen (display, 0);
       monitor = 0;
@@ -84,14 +86,13 @@ xfsm_splash_screen_new (GdkDisplay  *display,
       xfsm_splash_screen_load (splash, engine);
       if (G_LIKELY (splash->engine.setup != NULL))
         {
-          rc = xfce_rc_config_open (XFCE_RESOURCE_CONFIG,
-                                    "xfce4-session/xfce4-splash.rc",
-                                    TRUE);
-          g_snprintf (name, 128, "Engine: %s", engine);
-          splash_rc = xfsm_splash_rc_new (rc, name);
+          g_snprintf (name, sizeof(name), "/splash/engines/%s", engine);
+          channel = xfconf_channel_new_with_property_base ("xfce4-session",
+                                                           name);
+          splash_rc = xfsm_splash_rc_new (channel);
+          g_object_unref (channel);
           splash->engine.setup (&splash->engine, splash_rc);
           xfsm_splash_rc_free (splash_rc);
-          xfce_rc_close (rc);
 
           gdk_flush ();
         }
@@ -139,9 +140,8 @@ xfsm_splash_screen_run (XfsmSplashScreen *splash,
     }
   else
     {
-      xfce_gtk_window_center_on_monitor (GTK_WINDOW (dialog),
-                                         splash->engine.primary_screen,
-                                         splash->engine.primary_monitor);
+      gtk_window_set_screen (GTK_WINDOW (dialog), splash->engine.primary_screen);
+      gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 
       result = gtk_dialog_run (GTK_DIALOG (dialog));
     }
@@ -280,7 +280,7 @@ xfsm_splash_screen_load (XfsmSplashScreen *splash,
   void (*init) (XfsmSplashEngine *engine);
   gchar *filename;
 
-  filename = g_module_build_path (LIBDIR "/xfce4/splash/engines", engine);
+  filename = g_module_build_path (LIBDIR "/xfce4/session/splash-engines", engine);
   splash->module = g_module_open (filename, G_MODULE_BIND_LOCAL);
   g_free (filename);
 
